pub fn subsets(n: usize) -> Result<SubsetIter, CombError>Expand description
Construct a subset iterator, rejecting n too large for the u128 cursor.
pub fn subsets(n: usize) -> Result<SubsetIter, CombError>Construct a subset iterator, rejecting n too large for the u128 cursor.